@@ -7,6 +7,7 @@
 #include <schroedinger/schrocuda.h>
 #include <orc/orc.h>
 #include <schroedinger/opengl/schroopengl.h>
+#include <schroedinger/schroorc.h>
 
 extern int _schro_decode_prediction_only;
 extern int _schro_telemetry;
@@ -20,16 +21,18 @@ extern int _schro_motion_ref;
  * before any other function in the library.
  */
 void
-schro_init(void)
+schro_init (void)
 {
   const char *s;
   static int inited = FALSE;
 
-  if (inited) return;
+  if (inited)
+    return;
 
   inited = TRUE;
 
-  orc_init();
+  orc_init ();
+  schro_orc_init ();
 
   s = getenv ("SCHRO_DEBUG");
   if (s && s[0]) {
@@ -71,4 +74,3 @@ schro_init(void)
   schro_opengl_init ();
 #endif
 }
-
