@@ -5,12 +5,10 @@
 
 #include <schroedinger/schro.h>
 #include <schroedinger/schrowavelet.h>
-#include <schroedinger/schrooil.h>
 #include <schroedinger/schroorc.h>
 
-#define OIL_ENABLE_UNSTABLE_API
-#include <liboil/liboil.h>
-#include <liboil/liboilprofile.h>
+#include <orc/orc.h>
+#include <orc-test/orcprofile.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -24,7 +22,7 @@ int16_t c[N];
 
 int16_t table[65536];
 
-int oil_profile_get_min (OilProfile *prof)
+int orc_profile_get_min (OrcProfile *prof)
 {
   int i;
   int min;
@@ -98,6 +96,7 @@ schro_dequantise_s16_ref (int16_t *dest, int16_t *src, int quant_index,
   }
 }
 
+#if 0
 void
 schro_dequantise_s16_table (int16_t *dest, int16_t *src, int quant_index,
     schro_bool is_intra, int n)
@@ -108,6 +107,7 @@ schro_dequantise_s16_table (int16_t *dest, int16_t *src, int quant_index,
     dest[i] = table[src[i] + 32768];
   }
 }
+#endif
 
 #if 0
 void
@@ -161,11 +161,9 @@ generate_table (int16_t *table, int quant_index, schro_bool is_intra)
 void
 dequantise_speed (int quant_index, int n)
 {
-  OilProfile prof1;
-  OilProfile prof2;
-  OilProfile prof3;
+  OrcProfile prof1;
+  OrcProfile prof3;
   double ave1;
-  double ave2;
   double ave3;
   int i;
   int j;
@@ -176,9 +174,8 @@ dequantise_speed (int quant_index, int n)
   quant_factor = 10;
   quant_offset = 10;
 
-  oil_profile_init (&prof1);
-  oil_profile_init (&prof2);
-  oil_profile_init (&prof3);
+  orc_profile_init (&prof1);
+  orc_profile_init (&prof3);
 
   for(i=0;i<10;i++) {
     for(j=0;j<n;j++){
@@ -186,18 +183,13 @@ dequantise_speed (int quant_index, int n)
     }
     generate_table (table, quant_index, is_intra);
 
-    oil_profile_start (&prof1);
+    orc_profile_start (&prof1);
     schro_dequantise_s16_ref (b, a, quant_index, FALSE, n);
-    oil_profile_stop (&prof1);
-    oil_profile_start (&prof2);
-    schro_dequantise_s16_table (c, a, quant_index, FALSE, n);
-    oil_profile_stop (&prof2);
-#ifdef HAVE_ORC
+    orc_profile_stop (&prof1);
     memcpy (c, a, N*sizeof(int16_t));
-    oil_profile_start (&prof3);
+    orc_profile_start (&prof3);
     orc_dequantise_s16_ip (c, quant_factor, quant_offset + 2, n);
-    oil_profile_stop (&prof3);
-#endif
+    orc_profile_stop (&prof3);
 
 #if 0
     for(j=0;j<N;j++){
@@ -210,10 +202,9 @@ dequantise_speed (int quant_index, int n)
 #endif
   }
 
-  ave1 = oil_profile_get_min (&prof1);
-  ave2 = oil_profile_get_min (&prof2);
-  ave3 = oil_profile_get_min (&prof3);
-  printf("%d %d %g %g %g\n", quant_index, n, ave1, ave2, ave3);
+  ave1 = orc_profile_get_min (&prof1);
+  ave3 = orc_profile_get_min (&prof3);
+  printf("%d %d %g %g\n", quant_index, n, ave1, ave3);
 }
 
 
@@ -222,8 +213,8 @@ main (int argc, char *argv[])
 {
   int i;
 
+  orc_init();
   schro_init();
-  oil_init();
 
   for(i=0;i<N;i++){
     dequantise_speed (10, i);
